
#include <device.h>
#include <cytypes.h>

#define TABLE_LENGTH_SHORT  20
#define DMA_BYTES_PER_BURST 1
#define DMA_REQUEST_PER_BURST 1


/*sine LUK 20 values {128, 168, 203, 232, 250, 255, 250, 232, 203, 168, 128, 88, 53, 24, 6, 0, 6, 24, 53, 88, 128}*/
CYCODE const uint8 sine_LUK[TABLE_LENGTH_SHORT] = {0, 6, 24, 53, 88, 128, 168, 203, 232, 250, 255, 250, 232, 203, 168, 128, 88, 53, 24, 6};
CYCODE const uint8  cos_LUK[TABLE_LENGTH_SHORT] = {255, 250, 232, 203, 168, 128, 88, 53, 24, 6, 0, 6, 24, 53, 88, 128, 168, 203, 232, 250};


/* Variable declarations for DMA . 
* These variables are defined as global variables to avoid "may be used before being set" warning 
* issued by the PSoC 5 compilers  MDK/RVDS.In this case these variables are automatically initialized to zero */
uint8 DMA_Chan;               /* The DMA Channel */
uint8 DMA_TD[1];	          /* The DMA Transaction Descriptor (TD) */  	
uint8 DMA_1_Chan;             /* The DMA Channel */
uint8 DMA_1_TD[1];	          /* The DMA Transaction Descriptor (TD) */  	


//void main()
int main()
{
   /* Start VDAC  */
    VDAC8_Start();
    VDAC8_1_Start();
    
	
	/* Defines for DMA configuration */
    /* Source base address when PSoC5 is used */
	#define DMA_SRC_BASE (&sine_LUK[0]) 
    #define DMA_1_SRC_BASE (&cos_LUK[0]) 
	#define DMA_DST_BASE (CYDEV_PERIPH_BASE)  /* Destination base address */

    /* Step1 : DmaInitialize - Initialize the DMA channel
	 * Bytes per burst = 1, (8 bit data transferred to VDAC one at a time)
	 * Request per burst = 1 (this will cause transfer of the bytes only with every new request)
	 * High byte of source address = Upper 16 bits of Flash Base address for PSoC 3,
	                               = HI16(&sine_LUK) for PSoC 5
     * High byte of destination address =  Upper 16 bits of peripheral base address */
    DMA_Chan = DMA_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE) );
    DMA_TD[0]   = CyDmaTdAllocate();  								 
    CyDmaTdSetConfiguration(DMA_TD[0], TABLE_LENGTH_SHORT, DMA_TD[0], TD_INC_SRC_ADR | DMA__TD_TERMOUT_EN); 	 
    CyDmaTdSetAddress(DMA_TD[0], LO16((uint32)sine_LUK), LO16((uint32)VDAC8_Data_PTR) );
    CyDmaChSetInitialTd(DMA_Chan, DMA_TD[0]); 	
    //CyDmaChEnable(DMA_Chan, 1); 
        
	DMA_1_Chan = DMA_1_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, HI16(DMA_1_SRC_BASE), HI16(DMA_DST_BASE) );
	DMA_1_TD[0] = CyDmaTdAllocate();  								 
    CyDmaTdSetConfiguration(DMA_1_TD[0], TABLE_LENGTH_SHORT, DMA_1_TD[0], TD_INC_SRC_ADR | DMA_1__TD_TERMOUT_EN); 	 
    CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)cos_LUK), LO16((uint32)VDAC8_1_Data_PTR) );
    CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]); 	
	
    CyDmaChEnable(DMA_1_Chan, 1); 							
    CyDmaChEnable(DMA_Chan, 1); 
    
    CyDelay(1);
    /*switch clock via AND gate through to drq of the DMA channels*/
    Control_Reg_1_Write(1u);
    
	//CyDmaChSetRequest(DMA_1_Chan, CY_DMA_CPU_REQ);
    //CyDelay(1);
    
    for(;;)
    {
        //CyDmaChSetRequest(DMA_1_Chan, CY_DMA_CPU_REQ);
        //CyDelay(1);
    }
}

/* [] END OF FILE */
